<?php
/*
 * Plugin Name: External Link Redirection
 * Description: To redirect External Links to a Waiting Page with Ads inside your.
 * Version: 1.0.0
 * Author: Ashraf
 * Requires at least: 4.4
 * Tested up to: 4.9
 * Text Domain: external-link-redirection
 *
*/

if(!function_exists('add_action')){
	exit;
}

define( 'EXTLR_VERSION', '1.0.0');
define( 'EXTLR_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );

if(is_admin()){
	function extlr_activation_install() {
		global $wpdb;
	}
	register_activation_hook( __FILE__, 'extlr_activation_install' );	
}

function extlr_admin_menu_define(){
  add_menu_page(__('External Link','external-link-redirection'),__('External Link','external-link-redirection'), 'manage_options', 'extlr_page', 'extlr_settings_page','dashicons-download'); 
  add_submenu_page("extlr_page", __('الإعدادات', 'external-link-redirection'), __('Settings', 'external-link-redirection'), "manage_options", "extlr_page",'extlr_settings_page');
}

add_action('admin_menu', 'extlr_admin_menu_define');
function extlr_page_validate_options($input){
	add_settings_error( 'extlr_page_settings','settings_updated', __( 'Settings saved.', 'external-link-redirection') , 'updated' );
	return $input ;
}

function extlr_page_register_settings(){
	register_setting('extlr_page_settings','extlr_page_settings', 'extlr_page_validate_options' );
}

add_action( 'admin_init', 'extlr_page_register_settings' );

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ),  'extlr_plugin_action_links' );
function extlr_plugin_action_links($links){
	$setting_link  = admin_url( 'admin.php?page=extlr_page' );
	$plugin_links = array(
		'<a href="' . $setting_link . '">' . __( 'Settings', 'external-link-redirection' ) . '</a>',
		'<a target="_blank" href="https://youtu.be/7aBMCxvp-8M">' . __( 'How it Works', 'external-link-redirection' ) . '</a>',
	);
	return array_merge( $plugin_links, $links );  
}

function extlr_settings_page(){
	$extlr_page_settings = get_option('extlr_page_settings');

?>

<div id="extlr_page" class="wrap">

    <h2><?php echo __('External Link','external-link-redirection'); ?> - <?php echo __('Settings','external-link-redirection'); ?></h2>
	<p><?php echo __('Watch this video to learn how the plug-in works (<a href="https://youtu.be/7aBMCxvp-8M" target="_blank" style="font-weight: 700;">YouTube video url </a>)','external-link-redirection'); ?></p>
 
    <?php  

	settings_errors('extlr_page_settings');

	?>

    <form method="post" enctype="multipart/form-data" action="options.php">

        <?php 		

			settings_fields('extlr_page_settings');

			do_settings_sections('extlr_page');

        ?>

		<table class="form-table">

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:200px"><label for="active"><?php echo __('Activate','external-link-redirection'); ?></label></td>

				<td>

				<select name="extlr_page_settings[active]" id="active">

					<option <?php if(isset($extlr_page_settings['active']) && $extlr_page_settings['active'] == 0){ echo ' selected="selected" ';} ?> value="0"><?php echo __('No','external-link-redirection'); ?></option>

					<option <?php if(isset($extlr_page_settings['active']) && $extlr_page_settings['active'] == 1){ echo ' selected="selected" ';} ?> value="1"><?php echo __('Yes','external-link-redirection'); ?></option>

				</select>

				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:200px"><label for="software_fields_active"><?php echo __('Activate the technical details feature of the file','external-link-redirection'); ?></label></td>

				<td>

				<select name="extlr_page_settings[software_fields_active]" id="software_fields_active">

					<option <?php if(isset($extlr_page_settings["software_fields_active"]) && $extlr_page_settings["software_fields_active"] == 0){ echo ' selected="selected" ';} ?> value="0"><?php echo __('No','external-link-redirection'); ?></option>

					<option <?php if(isset($extlr_page_settings["software_fields_active"]) && $extlr_page_settings["software_fields_active"] == 1){ echo ' selected="selected" ';} ?> value="1"><?php echo __('Yes','external-link-redirection'); ?></option>

				</select>

				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('Page','external-link-redirection'); ?></label></td>
				<?php if(isset($extlr_page_settings["page_id"])){
						$page_id = $extlr_page_settings["page_id"];
					} else {
						$page_id = '';
					}
				?>
				<td><?php  echo wp_dropdown_pages(array("echo" => false, "selected" => $page_id, "name" => "extlr_page_settings[page_id]", "show_option_none" => __('select page','external-link-redirection'))) ; ?></td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('Download button title','external-link-redirection'); ?></label></td>

				<td><input name="extlr_page_settings[btn_label]" type="text" value="<?php  if(isset($extlr_page_settings['btn_label'])) { echo esc_html( __( $extlr_page_settings['btn_label'], 'external-link-redirection' ) ); } else { echo '';} ?>" class="regular-text" />

				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('The number of words displayed from the link article','external-link-redirection'); ?></label></td>

				<td><input name="extlr_page_settings[words]" type="text" value="<?php if(isset($extlr_page_settings['words'])){ echo esc_html( __( (int)$extlr_page_settings['words'], 'external-link-redirection' ) ); } else{ echo '25';} ?>" readonly class="regular-text" style="width:60px;" /> word
                   <span style="color:red; margin-left:5px;" > (Available on the Premium Version)</span>
				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('Waiting time before the download link appears','external-link-redirection'); ?></label></td>

				<td><input name="extlr_page_settings[timer]" type="text" value="<?php  if(isset($extlr_page_settings['timer'])){ echo esc_html( __( (int)$extlr_page_settings['timer'], 'external-link-redirection' ) ); }else { echo '3'; } ?>" readonly class="regular-text" style="width:60px;" /> second
                  <span style="color:red; margin-left:5px;" > (Available on the Premium Version) </span>
				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('Domain Link Transfer Exception','external-link-redirection'); ?></label></td>

				<td><textarea name="extlr_page_settings[domains]" style="width:50%;height:100px;" readonly ><?php if(isset($extlr_page_settings['domains'])) { echo esc_html( __( $extlr_page_settings['domains'], 'external-link-redirection' ) ); } else { echo ''; } ?></textarea>

					<br /><em><?php echo __('Each domain in a line.','external-link-redirection'); ?></em>
                    <span style="color:red; margin-left:5px;" > (Available on the Premium Version) </span>
				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('Exception to convert article links','external-link-redirection'); ?></label></td>

				<td><textarea name="extlr_page_settings[no_redirect_ids]" style="width:50%;height:100px;" readonly><?php if(isset($extlr_page_settings['no_redirect_ids'])) { echo esc_html( __( $extlr_page_settings['no_redirect_ids'], 'external-link-redirection' ) ); } else { echo ''; } ?></textarea>

					<br /><em><?php echo __('Every number in a line.','external-link-redirection'); ?></em>
                   <span style="color:red; margin-left:5px;" > (Available on the Premium Version) </span>
				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('Exclude displaying ads in article links','external-link-redirection'); ?></label></td>

				<td><textarea name="extlr_page_settings[no_ads_ids]" style="width:50%;height:100px;" readonly><?php if(isset($extlr_page_settings['no_ads_ids'])) { echo esc_html( __( $extlr_page_settings['no_ads_ids'], 'external-link-redirection' ) ); } else { echo '';} ?></textarea>

					<br /><em><?php echo __('Every number in a line.','external-link-redirection'); ?></em>
                    <span style="color:red; margin-left:5px;" > (Available on the Premium Version) </span>
				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('Advertisement at the top of the download page','external-link-redirection'); ?></label></td>

				<td><textarea name="extlr_page_settings[ads1]" style="width:50%;height:100px;" ><?php if(isset($extlr_page_settings['ads1'])) {  echo esc_html( __( $extlr_page_settings['ads1'], 'external-link-redirection' ) ); } else { echo ''; } ?></textarea>

					<br /><em><?php echo __('.','external-link-redirection'); ?></em>

				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('Ad in the middle of the download page','external-link-redirection'); ?></label></td>

				<td><textarea name="extlr_page_settings[ads2]" style="width:50%;height:100px;" readonly><?php if(isset($extlr_page_settings['ads2'])) { echo esc_html( __( $extlr_page_settings['ads2'], 'external-link-redirection' ) ); } else { echo '';} ?></textarea>

					<br /><em><?php echo __('.','external-link-redirection'); ?></em>
                    <span style="color:red; margin-left:5px;" > (Available on the Premium Version) </span>
				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('Advertisement at the bottom of the download page','external-link-redirection'); ?></label></td>

				<td><textarea name="extlr_page_settings[ads3]" style="width:50%;height:100px;" readonly><?php if(isset($extlr_page_settings['ads3'])) { echo esc_html( __( $extlr_page_settings['ads3'], 'external-link-redirection' ) ); } else { echo '';} ?></textarea>

					<br /><em><?php echo __('.','external-link-redirection'); ?></em>
                    <span style="color:red; margin-left:5px;" > (Available on the Premium Version) </span>
				</td>

			</tr>

			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px">&nbsp;</td>

				<td>

					<p class="submit">  

						<input name="submit" type="submit" class="button-primary" value="<?php echo __('Saving changes','external-link-redirection'); ?>" />

					</p>    

				</td>

			</tr>

			<tr valign="top" >

				<td colspan="2">&nbsp;</td>

			</tr>
			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >

				<td style="width:300px"><label><?php echo __('Devolped By','external-link-redirection'); ?>:</label></td>
				<td>
					<div style="color: #2271b1;">
					<a href="https://ahmed.com" target="_blank">Ashraf</a> © <a href="mailto:info@eduengteam.com" target="_blank">info@eduengteam.com</a> WhatsApp: 00970566660009 &copy; 2022</div>
				</td>
			</tr>
			<tr valign="top" style="background: #FFFFFF;border:1px solid #E1E3E3;padding:4px;margin:3px;" >
				<td style="width:300px"><label><?php //echo __('Devolped By','external-link-redirection'); ?>:</label></td>
				<td>
					<p>(If you want Premium Version Reach out to us at <a href="mailto:info@eduengteam.com" target="_blank" style="color:#3c434a">info@eduengteam.com</a>)</p>

				</td>
			</tr>
		</table>
 
    </form>

</div>

<style>

#extlr_page em{

	color:#A5A5A5;

}
a{
text-decoration: none;
}
</style>

<?php 

}





function extlr_page_content_filter($content){

	$get_post_id = 0;
	$extlr_page_settings = get_option('extlr_page_settings');

	

	if(!intval($extlr_page_settings['active'])){
		return $content;		
	}

	$extlr_page_settings['page_id'] = intval($extlr_page_settings['page_id']);


	if(!is_page($extlr_page_settings['page_id'])){
		return $content;		
	}



	$page_id = $extlr_page_settings['page_id'] ;	

	$page_url = get_page_link($page_id);

	if(isset($_GET['post-id'])){
		$get_post_id = intval($_GET['post-id']);
	}
	$get_link_id = 0;
	if(isset($_GET['link-id'])){
		$get_link_id = intval($_GET['link-id']);
	}


	if(!$get_post_id){
		return '<div style="margin:20px auto;padding:10px;text-align:center;font-size:22px;border:2px solid red;color:red;background:#F2D7D7;">الرابط خاطئ...</div>';
	}
	

	$postData    = get_post($get_post_id);

	if(!$postData->ID){
		return '<div style="margin:20px auto;padding:10px;text-align:center;font-size:22px;border:2px solid red;color:red;background:#F2D7D7;">الرابط خاطئ...</div>';
	}

	

	$no_ads_ids = array('-1');

	$extlr_page_settings['no_ads_ids'] = explode("\n",$extlr_page_settings['no_ads_ids']);

	foreach($extlr_page_settings['no_ads_ids'] as $no_ads_id){

		$no_ads_id = intval(trim($no_ads_id));

		if($no_ads_id){

			$no_ads_ids [] = $no_ads_id;

		}

	}

	

	$show_ads = true;

	if(in_array($postData->ID,$no_ads_ids)){

		$show_ads = false;

	}

	

	$links = array();

	$base_url = get_page_link($extlr_page_settings['page_id']);	

	$domains = strtolower($extlr_page_settings['domains']);	

	preg_match_all('#<a(.*)href="(.*)"(.*)</a>#Usi',$postData->post_content,$matches);	

	$link_id = 0 ;

	foreach((array)$matches[2] as $match_id => $match_link){		

		$link_host = @ parse_url($match_link)[host];

		if(!strpos('_'.$domains,strtolower($link_host))){

			$links[$link_id] = $match_link;

			$link_id++;

		}

	}

	

	$limit   = intval($extlr_page_settings['words']);

	$excerpt = preg_replace("#\<img(.*)\>#Usi",' ',$postData->post_content);

	$excerpt = preg_replace(" ([.*?])",'',$excerpt);

	$excerpt = strip_shortcodes($excerpt);

	$excerpt = strip_tags($excerpt);

	$excerpt = explode(' ',$excerpt,$limit);

	if (count($excerpt)>=$limit) {

		array_pop($excerpt);

	$excerpt = implode(" ",$excerpt).'...';

	} else {

		$excerpt = implode(" ",$excerpt);

	}	

	$excerpt = trim(preg_replace( '/s+/', ' ', $excerpt));

		

		

	$content = '';

	

	if(file_exists(get_template_directory() . '/framework/parts/meta-post.php')){

		ob_start();

		setup_postdata( $GLOBALS['post'] = $postData );

		include(get_template_directory() . '/framework/parts/meta-post.php');

		wp_reset_postdata();

		$ob = ob_get_contents();

		ob_end_clean ();

		$content .= $ob ;

	}

	

	

	if(!empty($extlr_page_settings["ads1"]) and $show_ads){

		$content .= '<div style="text-align:center;margin:10px auto;">'.esc_html($extlr_page_settings["ads1"]).'</div>';

	}

		

	$content .= $excerpt;

	

	if(!empty($extlr_page_settings["ads2"]) and $show_ads){

		$content .= '<div style="text-align:center;margin:10px auto;">'.esc_html($extlr_page_settings["ads2"]).'</div>';

	}

	

	if(intval($extlr_page_settings['software_fields_active'])){

		$software_details = get_post_meta($postData->ID, 'software_details',true);		

		$software_details = (array)$software_details;

		if(trim($software_details['software_detail_2_link'])){

			$software_details['software_detail_2'] = '<a href="'.esc_attr($software_details['software_detail_2_link']).'" target="_blank">'.esc_html($software_details['software_detail_2']).'</a>';

		}

		unset($software_details['software_detail_2_link']);

		$details = extlr_page_software_fields();

		foreach($details as $input_id => $input_title){

			if(trim($software_details[$input_id])){

				$content .= '<div style="margin:4px auto;padding:0px;text-align:center;font-size:16px;border:1px solid #EDEDED;color:#fff;background:#23527C;width:300px;">'. esc_attr($input_title) .'

							<div style="margin:0px auto;padding:2px;text-align:center;font-size:14px;border:0px solid #F9F9F9;color:black;background:#F9F9F9;">

							'. esc_html($software_details[$input_id]) .'

							</div>

						</div>';

			}

		}		

	}

	

	$timer = intval($extlr_page_settings['timer']);



	$new_title = 'صفحة تحميل ' . $postData->post_title ;

	$new_title = str_replace('صفحة تحميل تحميل','',$new_title);

	$new_title = str_replace('صفحة تحميل','',$new_title);

	

	$content .= '<div style="margin:2px auto;" >';

	$content .= '<div class="download-page-btn-download" style="display:none;" ><a href="'.esc_attr($links[$get_link_id]).'" style="display:block;text-decoration:none;width:180px;margin:0px auto;padding:10px;text-align:center;font-size:22px;border-bottom:2px solid green;color:#fff;background:#49A36A;">'.esc_html($extlr_page_settings["btn_label"]).'</a></div>';

	$content .= '<div id="download-page-timer" style="text-align:center;font-size:16px;margin:0px auto;padding:2px;">

	<div>Thank you for downloading  '.esc_html($new_title).'</div>

	<div id="download-page-counter">Your conversion is in progress and the file is checked, the download will start in <span style="color:blue;">'.esc_html($timer).'</span> second. If you are not transferred <a href="'.esc_attr($links[$get_link_id]).'" >click here</a> to download.</div>

	</div>';	

	$content .= '</div>';

	

	

	if(!empty($extlr_page_settings['ads3']) and $show_ads){

		$content .= '<div style="text-align:center;margin:10px auto;">'.esc_html($extlr_page_settings["ads3"]).'</div>';

	}

	

	add_action( 'wp_footer', 'extlr_page_content_css', 9999 );

	

	return $content;

}

add_filter( 'the_content', 'extlr_page_content_filter' ,99999);



function extlr_page_content_css() {



$extlr_page_settings = get_option('extlr_page_settings');

$timer = intval($extlr_page_settings['timer']);

?>

<script>

jQuery(document).ready(function($) {
	function extlr_page_timer(s){

		if(s<=0){

			 $( "#download-page-timer" ).hide();

			 $( ".download-page-btn-download" ).show();

			return true;

		}

		setTimeout(function(){

			var n = s-1;

			$( "#download-page-counter span" ).html(n);

			extlr_page_timer(n);

		},1000);

	}
	extlr_page_timer(<?php echo esc_html($timer);?>);

});

</script>

<?php

}





function extlr_page_title_filter( $title ,$id) {
	global $post;
	if(isset($_GET['post-id'])){
		$get_post_id = intval($_GET['post-id']);	
	} else {
		$get_post_id = '';
	}
	if(!$get_post_id){
		return $title;	
	}
	if(!is_page('download')){
		return $title;		
	}
	$extlr_page_settings = get_option('extlr_page_settings');
	if(intval($extlr_page_settings['page_id']) != $id){
		return $title;		
	}
		
	$postData    = get_post($get_post_id);
	if(!$postData->ID){
		return $title;
	}

	$new_title = $post->post_title.' ' . $postData->post_title;
	$new_title = 'صفحة تحميل ' . $postData->post_title;
	$new_title = str_replace('تحميل تحميل','تحميل',$new_title);

	return $new_title;


}
add_filter( 'the_title', 'extlr_page_title_filter' ,99,2);









function extlr_posts_content_filter($content){

	global $post;

	

	if(!is_single()){

		return $content;		

	}

	

	if($post->post_type != 'post'){

		return $content;		

	}

	

	$extlr_page_settings = get_option('extlr_page_settings');	

	if(!intval($extlr_page_settings['active'])){

		return $content;		

	}

	

	$no_redirect_ids = array('-1');

	$extlr_page_settings['no_redirect_ids'] = explode("\n",$extlr_page_settings['no_redirect_ids']);

	foreach($extlr_page_settings['no_redirect_ids'] as $no_redirect_id){

		$no_redirect_id = intval(trim($no_redirect_id));

		if($no_redirect_id){

			$no_redirect_ids [] = $no_redirect_id;

		}

	}

	

	if(in_array($post->ID,$no_redirect_ids)){

		return $content;

	}



	

	$base_url = get_page_link($extlr_page_settings['page_id']);	

	$domains = strtolower($extlr_page_settings['domains']);	

	preg_match_all('#<a(.*)href="(.*)"(.*)</a>#Usi',$content,$matches);	


	$link_id = 0 ;

	foreach((array)$matches[2] as $match_id => $match_link){		

		$link_host = @ parse_url($match_link)['host'];

		if(!strpos('_'.$domains,strtolower($link_host))){

			$new_link = $base_url.'?post-id='.$post->ID ;

			if($link_id){

				$new_link .= '&link-id='.$link_id;

			}
			//$label =  str_replace('>','',$matches[3][$match_id]);
			//$new_link = '<a '.esc_html($matches[1][$match_id]).' href="'.esc_attr($new_link).'"> '.esc_html($label).' </a>' ;
			$new_link = '<a '.esc_html($matches[1][$match_id]).' href="'.$new_link.'" '.$matches[3][$match_id].'</a>' ;

			$content  = str_replace($matches[0][$match_id],$new_link,$content);

			$link_id++;

		}

	}

	

	return $content;

}

add_filter( 'the_content', 'extlr_posts_content_filter' ,99999);





function extlr_page_add_meta_boxes(){ 

	$extlr_page_settings = get_option('extlr_page_settings');	

	if(intval($extlr_page_settings['software_fields_active'])){

		add_meta_box('extlr_page_software_fields','التفاصيل الفنية للبرنامج', 'extlr_page_meta_box_form','post', 'normal', 'high');  				

	}

}

add_action( 'add_meta_boxes', 'extlr_page_add_meta_boxes' );





function extlr_page_Software_save_meta( $post_ID ) { 
    global $post;
    if( $post->post_type == "post" ) {

        if (isset( $_POST['software_details'] ) ) {
			update_post_meta( $post_ID, 'software_details', sanitize_text_field($_POST['software_details']) ); 
        }
    }
}
add_action( 'save_post', 'extlr_page_Software_save_meta' );



function extlr_page_software_fields(){

	$details = array();

	$details['software_detail_1'] = 'اسم البرنامج';

	$details['software_detail_2'] = 'الشركة المنتجة';

	$details['software_detail_2_link'] = 'رابط الشركة المنتجة';

	$details['software_detail_3'] = 'متوافق مع';

	$details['software_detail_4'] = 'الرخصة';

	$details['software_detail_5'] = 'حجم البرنامج';

	$details['software_detail_6'] = 'واجهة البرنامج';

	$details['software_detail_7'] = 'النسخة / اصدار';

	return $details;

}





function extlr_page_meta_box_form($post) {

	$post_id = $post->ID;


	$software_details = get_post_meta($post_id, 'software_details',true);

	$software_details = (array)$software_details ;

	$details = extlr_page_software_fields();

	foreach($details as $input_id => $input_title){

		$outline  = '<label for="'.esc_attr($input_id) .'" style="width:120px; display:inline-block;vertical-align: top;">'. esc_html__($input_title) .':</label>';

		$outline .= '<input type="text" name="software_details['.$input_id .']" id="'.esc_attr($input_id) .'" class="wikipedia-table-input" value="'. esc_attr($software_details[$input_id]) .'" style="width:300px;"/>';

		echo '<div style="border:0px solid #ccc;margin-bottom:5px;">'.esc_html($outline).'</div>';
	}
}